# foxglove_msgs/msg/Grid
# A 2D grid of data

# Generated by https://github.com/foxglove/schemas

from dataclasses import dataclass
from pycdr2 import IdlStruct
from pycdr2.types import uint32, uint8, sequence
from ..builtin_interfaces.Time import Time
from ..geometry_msgs.Pose import Pose
from .Vector2 import Vector2
from .PackedElementField import PackedElementField
from .. import default_field

@dataclass
class Grid(IdlStruct, typename='foxglove_msgs/Grid'):
    # Timestamp of grid
    timestamp: Time = Time()

    # Frame of reference
    frame_id: str = ''

    # Origin of grid's corner relative to frame of reference; grid is positioned in the x-y plane relative to this origin
    pose: Pose = Pose()

    # Number of grid columns
    column_count: uint32 = 0

    # Size of single grid cell along x and y axes, relative to `pose`
    cell_size: Vector2 = Vector2()

    # Number of bytes between rows in `data`
    row_stride: uint32 = 0

    # Number of bytes between cells within a row in `data`
    cell_stride: uint32 = 0

    # Fields in `data`. `red`, `green`, `blue`, and `alpha` are optional for customizing the grid's color.
    fields: sequence[PackedElementField] = default_field([])

    # Grid cell data, interpreted using `fields`, in row-major (y-major) order
    data: uint8 = 0