# foxglove_msgs/msg/LocationFix
# A navigation satellite fix for any Global Navigation Satellite System

# Generated by https://github.com/foxglove/schemas

from dataclasses import dataclass
from pycdr2 import IdlStruct
from pycdr2.types import uint8, float64, array
from ..builtin_interfaces.Time import Time
from .. import default_field
from enum import Enum

class PositionCovarianceType(Enum):
    UNKNOWN=0
    APPROXIMATED=1
    DIAGONAL_KNOWN=2
    KNOWN=3

@dataclass
class LocationFix(IdlStruct, typename='foxglove_msgs/LocationFix'):
    # Timestamp of the message
    timestamp: Time = Time()

    # Frame for the sensor. Latitude and longitude readings are at the origin of the frame.
    frame_id: str = ''

    # Latitude in degrees
    latitude: float64 = 0

    # Longitude in degrees
    longitude: float64 = 0

    # Altitude in meters
    altitude: float64 = 0

    # Position covariance (m^2) defined relative to a tangential plane through the reported position. The components are East, North, and Up (ENU), in row-major order.
    position_covariance: array[float64, 9] = default_field([0] * 9)

    # If `position_covariance` is available, `position_covariance_type` must be set to indicate the type of covariance.
    position_covariance_type: uint8 = 0