# foxglove_msgs/msg/SceneEntity
# A visual element in a 3D scene. An entity may be composed of multiple primitives which all share the same frame of reference.

# Generated by https://github.com/foxglove/schemas

from dataclasses import dataclass
from pycdr2 import IdlStruct
from pycdr2.types import sequence
from ..builtin_interfaces.Time import Time
from ..builtin_interfaces.Duration import Duration
from .KeyValuePair import KeyValuePair
from .ArrowPrimitive import ArrowPrimitive
from .CubePrimitive import CubePrimitive
from .SpherePrimitive import SpherePrimitive
from .CylinderPrimitive import CylinderPrimitive
from .LinePrimitive import LinePrimitive
from .TriangleListPrimitive import TriangleListPrimitive
from .TextPrimitive import TextPrimitive
from .ModelPrimitive import ModelPrimitive
from .. import default_field

@dataclass
class SceneEntity(IdlStruct, typename='foxglove_msgs/SceneEntity'):
    # Timestamp of the entity
    timestamp: Time = Time()

    # Frame of reference
    frame_id: str = ''

    # Identifier for the entity. A entity will replace any prior entity on the same topic with the same `id`.
    id: str = ''

    # Length of time (relative to `timestamp`) after which the entity should be automatically removed. Zero value indicates the entity should remain visible until it is replaced or deleted.
    lifetime: Duration = Duration()

    # Whether the entity should keep its location in the fixed frame (false) or follow the frame specified in `frame_id` as it moves relative to the fixed frame (true)
    frame_locked: bool = False

    # Additional user-provided metadata associated with the entity. Keys must be unique.
    metadata: sequence[KeyValuePair] = default_field([])

    # Arrow primitives
    arrows: sequence[ArrowPrimitive] = default_field([])

    # Cube primitives
    cubes: sequence[CubePrimitive] = default_field([])

    # Sphere primitives
    spheres: sequence[SpherePrimitive] = default_field([])

    # Cylinder primitives
    cylinders: sequence[CylinderPrimitive] = default_field([])

    # Line primitives
    lines: sequence[LinePrimitive] = default_field([])

    # Triangle list primitives
    triangles: sequence[TriangleListPrimitive] = default_field([])

    # Text primitives
    texts: sequence[TextPrimitive] = default_field([])

    # Model primitives
    models: sequence[ModelPrimitive] = default_field([])
