# foxglove_msgs/msg/TrianglesMarker
# A marker representing a set of triangles or a surface tiled by triangles

# Generated by https://github.com/foxglove/schemas

from dataclasses import dataclass
from pycdr2 import IdlStruct
from pycdr2.types import uint32, sequence
from ..builtin_interfaces.Time import Time
from ..builtin_interfaces.Duration import Duration
from .KeyValuePair import KeyValuePair
from ..geometry_msgs.Pose import Pose
from ..geometry_msgs.Point import Point
from .Color import Color
from .. import default_field

@dataclass
class TrianglesMarker(IdlStruct, typename='foxglove_msgs/TrianglesMarker'):
    # Timestamp of the marker
    timestamp: Time = Time()

    # Frame of reference
    frame_id: str = ''

    # Identifier for the marker. A marker will replace any prior marker on the same topic with the same `id`.
    id: str = ''

    # Length of time (relative to `timestamp`) after which the marker should be automatically removed. Zero value indicates the marker should remain visible until it is replaced or deleted.
    lifetime: Duration = Duration()

    # Whether the marker should keep its location in the fixed frame (false) or follow the frame specified in `frame_id` as it moves relative to the fixed frame (true)
    frame_locked: bool = False

    # Additional user-provided metadata associated with the marker. Keys must be unique.
    metadata: sequence[KeyValuePair] = default_field([])

    # Origin of triangles relative to reference frame
    pose: Pose = Pose()

    # Vertices to use for triangles, interpreted as a list of triples (0-1-2, 3-4-5, ...)
    points: sequence[Point] = default_field([])

    # Solid color to use for the whole shape. One of `color` or `colors` must be provided.
    color: Color = Color()

    # Per-vertex colors (if specified, must have the same length as `points`). One of `color` or `colors` should be provided.
    colors: sequence[Color] = default_field([])

    # Indices into the `points` and `colors` attribute arrays, which can be used to avoid duplicating attribute data.
    # 
    # If omitted or empty, indexing will not be used. This default behavior is equivalent to specifying [0, 1, ..., N-1] for the indices (where N is the number of `points` provided).
    indices: sequence[uint32] = default_field([])
